//
//  NodeBox.cpp
//  node_parent
//
//  Created by Reza Ghobadinic on 2019-03-18.
//

#include "NodeBox.h"
#include "NodeTriangle.h"

Node* NodeBox::createNode()
{
    return NodeBox::create();
}

bool NodeBox::init()
{
    if(!Node::init())
        return false;
    
    m_isDrawn = false;          // Make sure to draw once
    m_rotateAngle = 0.5;        // Rotation angle value
    m_rotateDirection = 1.0;    // Rotation direction
    m_scaleDelta = 0.001;       // Scale value
    m_scaleDirection = 1.0;     // Scale direction
    m_childKillerCounter = 0;   // Tag ID for killing the child
    
    // Creating four triangles
    auto triangle1 = NodeTriangle::create();
    auto triangle2 = NodeTriangle::create();
    auto triangle3 = NodeTriangle::create();
    auto triangle4 = NodeTriangle::create();
    
    // Position each triangle on the box's corners
    triangle1->setPosition(100, 100);
    triangle2->setPosition(100, -100);
    triangle3->setPosition(-100, 100);
    triangle4->setPosition(-100, -100);
    
    // Assigning the triangles as children with a tag
    addChild(triangle1, 0, 1); // child tagged 1
    addChild(triangle2, 0, 2); // child tagged 2
    addChild(triangle3, 0, 3); // child tagged 3
    addChild(triangle4, 0, 4); // child tagged 4
    
    // Repeats every frame
    scheduleUpdate();
    // Reverse direction every 3 seconds
    schedule(SEL_SCHEDULE(&NodeBox::reverseDirection), 3.0);
    // Kill a child every 3 seconds, repeat 4 times and start with 3 seconds delay
    schedule(SEL_SCHEDULE(&NodeBox::killNextChild), 3.0, 4, 3);
    
    return true;
}

void NodeBox::update(float delta)
{
    // Increase or Decrease the rotation angle
    auto rotation = getRotation();
    rotation += (m_rotateAngle * m_rotateDirection);
    setRotation(rotation);
    
    // Increase or Decrease the scale value
    auto scale = getScale();
    scale += (m_scaleDelta * m_scaleDirection);
    setScale(scale);
}

void NodeBox::reverseDirection(float delta)
{
    // Change the scale and rotaton directions
    m_rotateDirection *= -1.0;
    m_scaleDirection  *= -1.0;
}

void NodeBox::killNextChild(float delta)
{
    // Keeps track of the tag number to remove
    m_childKillerCounter++;
    removeChildByTag(m_childKillerCounter);
}

void NodeBox::draw(Renderer* renderer, const Mat4& transform, uint32_t flags)
{
    if(!m_isDrawn)
    {
        auto draw = DrawNode::create();
        draw->drawLine(Vec2(-100, -100), Vec2(-100, +100), Color4F(1.0, 1.0, 1.0, 1.0));
        draw->drawLine(Vec2(+100, -100), Vec2(+100, +100), Color4F(1.0, 1.0, 1.0, 1.0));
        draw->drawLine(Vec2(-100, -100), Vec2(+100, -100), Color4F(1.0, 1.0, 1.0, 1.0));
        draw->drawLine(Vec2(-100, +100), Vec2(+100, +100), Color4F(1.0, 1.0, 1.0, 1.0));
        addChild(draw);
        m_isDrawn = true;
    }
}
